# Targon

Easy to setup modulable crawler for Riot API.



Targon is a layer on top of [Pantheon](https://github.com/Canisback/pantheon) to abstract most of the tedious asyncio development. It offers a set of Callers, Queues and Parsers allowing to setup an efficient crawler while allowing to integrated custom code to use the data.

WARNING : Work Heavily on Progress.


## How to use

To install : 
```
pip install targon
```